@@ -87,6 +87,7 @@ drgeniusMDI::drgeniusMDI ()
   p_drgeoStatusbar = glade_xml_get_widget (xml, "drgeoStatusbar");
   p_windowsMenu = glade_xml_get_widget (xml, "windowsMenu");
   p_macroMenu = glade_xml_get_widget (xml, "macroMenu");
+  p_animationMenu = glade_xml_get_widget (xml, "animationMenu");
 
   // set the submenu of macro and windows
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (p_macroMenu), gtk_menu_new ());  gtk_menu_item_set_submenu (GTK_MENU_ITEM (p_windowsMenu), gtk_menu_new ());
@@ -309,6 +310,7 @@ drgeniusMDI::reconcile_grayout_widget ()
 	  gtk_widget_set_sensitive (p_gridItemSc, TRUE);
 	  gtk_widget_set_sensitive (p_printFigure, TRUE);
 	  gtk_widget_set_sensitive (p_macroMenu, TRUE);
+	  gtk_widget_set_sensitive (p_animationMenu, TRUE);
 	}
       else if (p_activeView->childType() == EDITOR_CHILD)
 	{
@@ -321,6 +323,7 @@ drgeniusMDI::reconcile_grayout_widget ()
 	  gtk_widget_set_sensitive (p_gridItemSc, FALSE);
 	  gtk_widget_set_sensitive (p_printFigure, FALSE);
 	  gtk_widget_set_sensitive (p_macroMenu, FALSE);
+	  gtk_widget_set_sensitive (p_animationMenu, FALSE);
 	}
     }
   else
@@ -340,6 +343,7 @@ drgeniusMDI::reconcile_grayout_widget ()
       gtk_widget_set_sensitive (p_saveItem, FALSE);
       gtk_widget_set_sensitive (p_printFigure, FALSE);
       gtk_widget_set_sensitive (p_macroMenu, FALSE);
+      gtk_widget_set_sensitive (p_animationMenu, FALSE);
 
     }
 }
@@ -1735,7 +1739,7 @@ on_about_activate (GtkWidget * widget, gpointer data)
   img = gtk_image_new_from_file (DRGEO_ICONDIR "/drgeo-book.png");
   ofsetLogo = gtk_image_new_from_file (DRGEO_ICONDIR "/ofset-logo.png");
   // VERSION
-  str = g_strconcat ("GNU Dr. Geo " VERSION, _("\nFree Interactive Geometry\n\n(c) Copyright 1996-2000 H. Fernandes  \n(c) Copyright 2000 L. Gauthier\n(c) Copyright 2000-2003 OFSET\nTranslation: translator_name"), NULL);
+  str = g_strconcat ("GNU Dr. Geo " VERSION, _("\nFree Interactive Geometry\n\n(c) Copyright 1996-2005 H. Fernandes  \n(c) Copyright 2000 L. Gauthier\n(c) Copyright 2000-2005 OFSET\nTranslation: translator_name"), NULL);
   l = gtk_label_new (str);
   g_free (str);
   gtk_box_pack_start (GTK_BOX (hbox), ofsetLogo, FALSE, FALSE, 5);
@@ -1946,3 +1950,57 @@ preferences_box_cb (GtkWidget * widget, gpointer data)
 {
   initPreferencesBox ();
 }
+
+/* ------- Animation --------------*/
+
+static void
+setAnimationMode (gdouble step)
+{
+  drgeoFigure *figure;
+  drgeoGtkDrawable *area;
+  GtkWidget *label;
+  const gchar *text;
+
+  // go in animation mode
+  if (mdi->activeView ()->childType () != FIGURE_CHILD)
+    {
+      g_printerr ("drgenius_mdi::on_animation?_activate not a FIGURE_CHILD while switching to animation menu\n");
+      return;
+    }
+  figure = ((geoView *) mdi->activeView ())->figure ();
+  area = (drgeoGtkDrawable *) figure->getDrawable ();
+  if (figure->getMode () != ANIMATION_MODE)
+    {
+      area->setTool (area->animationToolDialogLess);
+      figure->setMode (ANIMATION_MODE, NULL);
+      mdi->setMessage (_("Select a free point to animate it"));
+    }
+
+  // Set the drgeoAnimationDialogLess to the selected step
+  ((drgeoAnimationDialogLess *)area->animationToolDialogLess)
+    ->setStep (step);
+}
+
+void
+on_animation1_activate (GtkWidget * widget, gpointer data)
+{
+  setAnimationMode (0.01);
+}
+void
+on_animation2_activate (GtkWidget * widget, gpointer data)
+{
+  setAnimationMode (0.02);
+
+}
+void
+on_animation3_activate (GtkWidget * widget, gpointer data)
+{
+  setAnimationMode (0.04);
+
+}
+void
+on_animation4_activate (GtkWidget * widget, gpointer data)
+{
+  setAnimationMode (0.08);
+
+}
