@@ -66,7 +66,7 @@ class drgeniusMDI
     *p_saveItem, *p_saveAsItem, *p_saveMultipleItem, *p_printFigure,
     *p_exportItem, *p_exportPreferencesItem, *p_closeItem, 
     *p_drgeoStatusbar, *p_noteBook, *p_drgeoMDIVbox, *p_nullViewWidget,
-    *p_windowsMenu, *p_macroMenu;
+    *p_windowsMenu, *p_macroMenu, *p_animationMenu;
   GtkTooltips *p_tooltipsMacro;
   GtkWindow *p_mainWindow;
   drgeniusView *p_activeView;
@@ -149,7 +149,11 @@ G_MODULE_EXPORT void customize_interface_cb (GtkWidget * widget, gpointer data);
 G_MODULE_EXPORT void on_contents_activate (GtkWidget *widget, gpointer data);
 /*----- Property box ----------- */
 G_MODULE_EXPORT void preferences_box_cb (GtkWidget * widget, gpointer data);
-
+/*------ Animation -------*/
+G_MODULE_EXPORT void on_animation1_activate(GtkWidget * widget, gpointer data);
+G_MODULE_EXPORT void on_animation2_activate(GtkWidget * widget, gpointer data);
+G_MODULE_EXPORT void on_animation3_activate(GtkWidget * widget, gpointer data);
+G_MODULE_EXPORT void on_animation4_activate(GtkWidget * widget, gpointer data);
 }
 
 #endif /* DRGENIUS_MDI_H */
