@@ -81,7 +81,8 @@ enum toolbarmode
   SAUVEGARDE_MODE,
   OUVERTURE_MODE,
   NOUVEAU_MODE,
-  PRINTING_AREA_MODE
+  PRINTING_AREA_MODE,
+  ANIMATION_MODE
 };
 
 /* used to select an object for construction. A non zero value after a
