@@ -295,6 +295,7 @@ drgeoDrawableUI::drgeoDrawableUI ()
 {
   this->tool = NULL;
   selectTool = new drgeoSelectTool;
+  animationToolDialogLess = new drgeoAnimationDialogLess;
   printingAreaTool = new drgeoPrintingAreaTool;
   buildTool = new drgeoBuildTool;
   styleTool = new drgeoStyleTool;
@@ -309,6 +310,7 @@ drgeoDrawableUI::drgeoDrawableUI ()
 drgeoDrawableUI::~drgeoDrawableUI ()
 {
   printf ("drgeoDrawableUI destructor \n");
+  delete animationToolDialogLess;
   delete macroPlayToolDialogLess;
   delete macroPlayTool;
   delete printingAreaTool;
