@@ -227,7 +227,7 @@ public:
   // tools for selection mode and build mode
   drgeoTool *selectTool, *buildTool, *macroBuildTool, *deleteTool,
     *macroPlayTool, *macroPlayToolDialogLess, *styleTool, 
-    *propertyTool, *printingAreaTool;
+    *propertyTool, *printingAreaTool, *animationToolDialogLess;
 
   class drgeoMacroBuilder *builder;
   class drgeoMacroPlayer *player;
