@@ -914,6 +914,11 @@ drgeoFigure::mouseSelection (drgeoPoint & mouse)
 	      while (--nb != 0);
 	    }
 	  break;
+	case ANIMATION_MODE:
+	  trouve = itemsUnderMouse (mouse, FALSE);
+	  if (trouve)
+	    filterItems (underMouse, FREE_PT_ON_CURVE);
+	  break;
 	case EFFACE_OBJET_MODE:
 	  // Remove mode
 	  trouve = itemsUnderMouse (mouse, FALSE);
@@ -923,6 +928,25 @@ drgeoFigure::mouseSelection (drgeoPoint & mouse)
   return &underMouse;
 }
 
+void
+drgeoFigure::filterItems (liste_elem &items, objectCategory categories)
+{
+  gint nb;
+  geometricObject *fig;
+  objectCategory category;
+
+  items.init_lire ();
+  nb = items.nb_elem;
+  do
+    {
+      fig = (geometricObject *) items.lire (0);
+      if ( (fig->getCategory() & categories) == 0)
+	underMouse.supprime ((void *) fig);
+    }
+  while (--nb != 0);
+
+}
+
 void
 drgeoFigure::dragSelection (drgeoPoint & start, drgeoPoint & mouse)
 {
@@ -1295,6 +1319,9 @@ drgeoFigure::flashSelection (bool drawGrey)
   drgeoColorType color;
   geometricObject *fig;
 
+  if (mode == ANIMATION_MODE)
+    return;
+
   if (!blinkOn)
     return;
 
