@@ -78,7 +78,7 @@ ScmInterface::make_pointOnCurve (SCM name, SCM c, SCM v)
   parents->ajoute ((void *) gh_scm2ulong (c));
 
   item = (geometricObject *) 
-    new point (gh_scm2double (v), *parents, figure->getFigureList ());
+    new point (gh_scm2double (v), *parents, FALSE, figure->getFigureList ());
   setObjectName (name, item);
   figure->addToFigureListNoRedraw (item, TRUE);
   return gh_ulong2scm ((unsigned long) item);
