@@ -25,7 +25,13 @@
 #include <string.h>
 
 #include "drgeo_tool.h"
+#include "drgeo_point.h"
 
+drgeoState 
+drgeoTool::getDrgeoState ()
+{
+  return state;
+}
 
 // -------------------------------------------------
 // Implementation for the Null tool, this tool does nothing.
@@ -793,6 +799,133 @@ selectMacro (const gchar *name)
   return player->setMacro (name);
 }
 
+// -----------------------------------------------------
+// Dialog Less Animation Tool, used for animation.
+// From the menu barre
+// -----------------------------------------------------
+static int
+timer_cb (drgeoAnimationDialogLess * tool)
+{
+  if (tool->getDrgeoState () == drgeoStateAnimated)
+    tool->animate ();
+  return (TRUE);		// Make sure the CallBack will be
+  // called again and again... 
+}
+
+void
+drgeoAnimationDialogLess::initialize (drgeoDrawableUI * drawable)
+{
+  drgeoBuildTool::initialize (drawable);
+  step = 0.05;
+  timeoutTag = 0;
+  itemUnderMouse = NULL;
+  this->drawable = drawable;
+}
+
+void
+drgeoAnimationDialogLess::handlePress (drgeoDrawableUI * drawable, drgeoPoint & where)
+{
+  liste_elem *list;
+  int i;
+
+  // Do nothing if no figure is currently associated with this drawable.
+  if (drawable->figure != NULL)
+    {
+      drawable->removeTip ();
+      switch (state)
+	{
+	case drgeoStateAnimated:
+	  // user click while a point is animated,
+	  // stop and reset the animation
+	  reset ();
+	  state = drgeoStateNeutral;
+	  break;
+	case drgeoStateItemChoice:
+	  // The user has not chosen any item, so revert to neutral
+	  // state.
+	  state = drgeoStateNeutral;
+	  // Fall through!  This is really what is wanted here.
+	case drgeoStateNeutral:
+	  // The mouse button is being pressed, check if there are items
+	  // near the mouse.
+	  list = drawable->figure->mouseSelection (where);
+	  list->init_lire ();
+	  if (list->nb_elem == 1)
+	    {
+	      // Only one item is selected, add it to the selection.
+	      state = drgeoStateAnimated;
+	      last = where;
+	      handleChoice (drawable, (geometricObject *) list->lire (0));
+	    }
+	  else if (list->nb_elem > 1)
+	    {
+	      // Several items are selected at once, we must prompt the
+	      // user for a choice.  When the user is done with his
+	      // choice the handleChoice method will be invoked.
+	      state = drgeoStateItemChoice;
+	      last = where;
+	      drawable->chooseItem (list);
+	    }
+	  break;
+	default:
+	  // If we get there, then there's a problem with the event
+	  // handling code... XXX
+	  break;
+	}
+    }
+}
+void 
+drgeoAnimationDialogLess::handleChoice (drgeoDrawableUI * drawable,
+					geometricObject * item)
+{
+  this->item = item;
+  state = drgeoStateAnimated;
+  animatedAbscissa = initialAbscissa = ((point * )item)->getAbscissa ();
+  timeoutTag =
+    gtk_timeout_add (100, (GtkFunction) timer_cb, (gpointer) this);
+}
+
+void
+drgeoAnimationDialogLess::finish (drgeoDrawableUI * drawable)
+{
+  reset ();
+}
+
+void
+drgeoAnimationDialogLess::animate ()
+{
+  animatedAbscissa += step;
+  if (step > 0 && animatedAbscissa > 1.)
+    animatedAbscissa -= 1.;
+  if (step < 0 && animatedAbscissa < 0)
+    animatedAbscissa += 1.;
+  if (item)
+    {
+      ((point *) item)->setAbscissa (animatedAbscissa);
+      drawable->getFigure()->updateItems ();
+      drawable->refresh ();
+    }
+}
+
+void
+drgeoAnimationDialogLess::reset ()
+{
+  if (timeoutTag)
+    gtk_timeout_remove (timeoutTag);
+  timeoutTag = 0;
+  if (item)
+    ((point *) item)->setAbscissa (initialAbscissa);
+  drawable->getFigure()->updateItems ();
+  drawable->refresh ();
+  itemUnderMouse = NULL;
+}
+
+void
+drgeoAnimationDialogLess::setStep (gdouble aStep)
+{
+  step = aStep;
+}
+
 // -----------------------------------------------------
 // Delete Tool, used for object deletion.
 // -----------------------------------------------------
@@ -861,7 +994,7 @@ handleChoice (drgeoDrawableUI * drawable, geometricObject * item)
   // Forward this item to the style dialog.
   if (dialog && item)
     {
-      // Update the dialog that match the item nwly selected.
+      // Update the dialog that match the item newly selected.
       drawable->figure->clearSelection ();
       drawable->figure->addToSelection (xxx, item);
       dialog->edit (item);
