@@ -39,7 +39,8 @@ enum drgeoState
   drgeoStateItemChoice,		// A choice is being done by the user.
   drgeoStateItemSelected,	// An item has just been selected.
   drgeoState1stCornerSelected,  // 1st corner of the printing area selected.
-  drgeoState2ndCornerSelected   // 2nd corner of the printing area selected.
+  drgeoState2ndCornerSelected,  // 2nd corner of the printing area selected.
+  drgeoStateAnimated            // A point is animated
 };
 
 class drgeoTool
@@ -56,6 +57,7 @@ public:
   virtual void handleChoice (class drgeoDrawableUI * drawable,
 			     class geometricObject * item) = 0;
   virtual void finish (class drgeoDrawableUI * drawable) = 0;
+  drgeoState getDrgeoState ();
 protected:
   // This state variable is used in event handling methods.
     drgeoState state;
@@ -181,6 +183,26 @@ private:
   class drgeoMacroPlayer * player;
 };
 
+
+class drgeoAnimationDialogLess:public drgeoBuildTool
+{
+public:
+  void initialize (class drgeoDrawableUI * drawable);
+  void handlePress (class drgeoDrawableUI * drawable,
+		    class drgeoPoint & where);
+  void handleChoice (drgeoDrawableUI * drawable,
+		     geometricObject * item);
+  void finish (class drgeoDrawableUI * drawable);
+  void animate ();
+  void reset ();
+  void setStep (gdouble aStep);
+private:
+  gdouble initialAbscissa, animatedAbscissa, step;
+  gint timeoutTag;
+  drgeoDrawableUI *drawable;
+};
+
+
 class drgeoStyleTool:public drgeoBuildTool
 {
 public:
