@@ -38,6 +38,9 @@
 #include "drgeo_polygon.h"
 #include "drgeo_script.h"
 #include "traite.h"
+#include "drgenius_mdi.h"
+
+extern drgeniusMDI *mdi;
 
 
 /* Helper function to load/save a XML macro */
@@ -171,7 +174,8 @@ macro::play (drgeoFigure * aFigure)
 	createdFromMacro = TRUE;
       else
 	createdFromMacro = FALSE;
-      n->fig = (void *) createItem (findParent (n->liste_parent, parentList),
+      n->fig = (void *) createItem (findParent (n->liste_parent, 
+						parentList),
 				    n, createdFromMacro,
 				    aFigure->getFigureList ());
     }
@@ -216,10 +220,17 @@ macro::createItem (liste_elem & parentList, noyau_macro * n,
 			 createdFromMacro, figureList, 0);
       break;
     case FREE_PT:
-    case FREE_PT_ON_CURVE:
+      g_print ("%lf,%lf\n",*((double *) n->extra),
+	       *((double *) n->extra + 1)); 
+      p.setX (*((double *) n->extra));
+      p.setY (*((double *) n->extra + 1));
       fig = new point (p, parentList, (pointType) n->type,
 		       createdFromMacro, figureList);
       break;
+    case FREE_PT_ON_CURVE:
+      fig = new point ( *((double *) n->extra), parentList,		
+		       createdFromMacro, figureList);
+      break;
     case LINE:
       fig = new line (parentList, (lineType) n->type,
 		      createdFromMacro, figureList);
@@ -259,7 +270,8 @@ macro::createItem (liste_elem & parentList, noyau_macro * n,
       break;
     case NUMERIC:
       if ((numericType) n->type == FREE_VALUE)
-	fig = new numeric (p, 0, (numericType) n->type, createdFromMacro);
+	fig = new numeric (p, *((double *) n->extra), 
+			   (numericType) n->type, createdFromMacro);
       else
 	fig = new numeric (p, parentList, (numericType) n->type,
 			   createdFromMacro, figureList);
@@ -330,15 +342,13 @@ drgeoMacroRegistry::load (xmlNodePtr macroXml)
   if ((tree = xml_search_child (macroXml, "input")) == NULL)
     {
       fprintf (stderr,
-	       "drgeoMacroRegistry::load : no input element in macro %s\n",
-	       name);
+	       "drgeoMacroRegistry::load : no input element in macro %s\n", name);
       return false;
     }
   if ((tree = xml_search_child (tree, "kernel")) == NULL)
     {
       fprintf (stderr,
-	       "drgeoMacroRegistry::load : no kernel element in input element in macro %s\n",
-	       name);
+	       "drgeoMacroRegistry::load : no kernel element in input element in macro %s\n", name);
       return false;
     }
   pi = 0;
@@ -352,15 +362,13 @@ drgeoMacroRegistry::load (xmlNodePtr macroXml)
   if ((tree = xml_search_child (macroXml, "intermediate")) == NULL)
     {
       fprintf (stderr,
-	       "drgeoMacroRegistry::load : no intermediate element in macro %s\n",
-	       name);
+	       "drgeoMacroRegistry::load : no intermediate element in macro %s\n", name);
       return false;
     }
   if ((tree = xml_search_child (tree, "kernel")) == NULL)
     {
       fprintf (stderr,
-	       "drgeoMacroRegistry::load : no kernel element in intermediate element in macro %s\n",
-	       name);
+	       "drgeoMacroRegistry::load : no kernel element in intermediate element in macro %s\n", name);
       return false;
     }
   pf = 0;
@@ -374,8 +382,6 @@ drgeoMacroRegistry::load (xmlNodePtr macroXml)
     }
 
   mac = new macro (name, description, pi, pf);
-  g_free (name);
-  g_free (description);
   /* rebrowse the input element and insert them in the macro
      we alreay know input element exist and there is 
      at least one kernel element in it */
@@ -386,9 +392,10 @@ drgeoMacroRegistry::load (xmlNodePtr macroXml)
       if (!xml_get_value_int (tree, "category", &category))
 	{
 	  fprintf (stderr,
-		   "drgeoMacroRegistry::load : no category in input kernel in macro %s\n",
-		   name);
+		   "drgeoMacroRegistry::load : no category in input kernel in macro %s\n", name);
 	  delete mac;
+	  g_free (name);
+	  g_free (description);
 	  return false;
 	}
       mac->ajoute (NULL, 0, (objectCategory) category, NULL, FALSE, NULL);
@@ -402,17 +409,21 @@ drgeoMacroRegistry::load (xmlNodePtr macroXml)
   if (!xmlLoadKernel (tree, mac) || (tree == NULL))
     {
       fprintf (stderr,
-	       "drgeoMacroRegistry::load : error building the intermediate kernel in macro %s\n",
-	       name);
+	       "drgeoMacroRegistry::load : error building the intermediate kernel in macro %s\n", name);
       delete mac;
+      g_free (name);
+      g_free (description);
       return false;
     }
   this->add (mac);
+  mdi->addMacroMenuItem (name, description);
+  g_free (name);
+  g_free (description);
   return true;
 }
 
 bool
-drgeoMacroRegistry::save (char *macroName, xmlNodePtr macroXml)
+drgeoMacroRegistry::save (const gchar *macroName, xmlNodePtr macroXml)
 {
   macro *mac;
   xmlNodePtr tree, subtree, subsubtree, elem;
@@ -473,7 +484,7 @@ drgeoMacroRegistry::add (macro * aMacro)
 }
 
 macro *
-drgeoMacroRegistry::find (char *aName)
+drgeoMacroRegistry::find (const gchar *aName)
 {
   macro *aMacro = NULL;
   int nb;
@@ -551,12 +562,37 @@ xmlSaveKernel (xmlNodePtr tree, noyau_macro * kernel)
   g_free (attr);
   if (kernel->extra != NULL)
     {
-      if (kernel->category == CONSTRAINED_PT)
-	// extra argument for intersection point
-	attr = g_strdup_printf ("%d", *((int *) kernel->extra));
-      else if (kernel->category == SCRIPT)
-	// extra argument for script
-	attr = g_strdup_printf ("%s", (gchar *) kernel->extra);      
+      switch (kernel->category)
+	{
+	case CONSTRAINED_PT:
+	  // extra argument for intersection point
+	  attr = g_strdup_printf ("%d", *((int *) kernel->extra));
+	  break;
+	case SCRIPT:
+	  // extra argument for script
+	  attr = g_strdup_printf ("%s", (gchar *) kernel->extra);
+	  break;
+	case FREE_PT_ON_CURVE:
+	  // extra argument for free point on curve is its abscissa
+	  attr = g_strdup_printf ("%lf", *((double *) kernel->extra));
+	  break;
+	case FREE_PT:
+	  // extra argument for free point is its coordinates
+	  attr = g_strdup_printf ("%lf;%lf", *((double *) kernel->extra),
+				  *((double *)kernel->extra + 1));	  
+	  break;
+	case NUMERIC:
+	  // extra argument for free value is its value
+	  if (kernel->type == FREE_VALUE)
+	    {
+	      attr = g_strdup_printf ("%lf", *((double *) kernel->extra));
+	      break;
+	    }
+	  // Fall through, this is what we want
+	default:
+	  g_printerr ("macro::xmlSaveKernel kernel->extra value to a not handled category object\n");
+	  attr = NULL;
+	}
       xmlSetProp (subtree, BAD_CAST "extra", BAD_CAST attr);
       g_free (attr);
     }
@@ -603,21 +639,54 @@ xmlLoadKernel (xmlNodePtr tree, macro * mac)
       extra = (void *) xml_value_get (tree, "extra");
       if (extra != NULL)
 	{
-	  if ( ((objectCategory) category) == CONSTRAINED_PT)
+	  switch ((objectCategory) category)
 	    {
+	    case CONSTRAINED_PT:
 	      int * tmp;
 	      tmp = (int *) g_malloc (sizeof (int));
 	      xml_get_value_int (tree, "extra", tmp);
 	      g_free (extra);
 	      extra = (void *) tmp;
-	    }
-	  // Nothing to be done to fetch the extra value for script
-	  //
-	  // If not a script, set extra to NULL
-	  else if (((objectCategory) category) != SCRIPT)
-	    {
+	      break;
+	    case FREE_PT_ON_CURVE:
+	      double *x;
+	      x = (double *) g_malloc (sizeof (double));
+	      xml_get_value_double (tree, "extra", x);
+	      g_free (extra);
+	      extra = (void *) x;
+	      break;
+	    case FREE_PT:
+	      double *coordinate;
+	      coordinate = (double *) g_malloc (2 * sizeof(double));
+	      if (sscanf ((const char *) extra,"%lf;%lf", coordinate, coordinate + 1) != 2)
+		{
+		  *coordinate = 0.0;
+		  *(coordinate + 1) = 0.0;
+		  g_printerr ("macro::xmlLoadKernel cannot scan coordinate of free point\n");
+		}
+	      g_free (extra);
+	      extra = (void *) coordinate;
+	      break;
+  	    case SCRIPT:
+	      // Nothing to be done to fetch the extra value for script
+	      break;
+	    case NUMERIC:
+	      if (type == FREE_VALUE)
+		{
+		  double *val;
+		  val = (double *) g_malloc (sizeof (double));
+		  xml_get_value_double (tree, "extra", val);
+		  g_free (extra);
+		  extra = (void *) val;
+		  break;
+		}
+	      // just fall through, this is what we want
+	    default:
+	      // default, set extra to NULL
 	      g_free (extra);
 	      extra = NULL;
+	      g_printerr ("macro::xmlLoadKernel extra value to a not handled category object\n");
+	      break;
 	    }
 	}
 
@@ -628,14 +697,18 @@ xmlLoadKernel (xmlNodePtr tree, macro * mac)
 	  subtree = xml_search_next (subtree->next, "parent");
 	  parentQty++;
 	}
-      if (parentQty == 0)
-	/* all intermediate item must have at least one parent */
+      if (parentQty == 0 &&
+	  (objectCategory) category != FREE_PT &&
+	  category != SCRIPT &&
+	  !(category == NUMERIC && type == FREE_VALUE))
+	/* all intermediate item but FREE_PT, FREE_VALUE, SCRIPT must
+	   have at least one parent */
 	return false;
       parent = new int[parentQty + 1];
       parent[0] = parentQty;
       pi = 1;
       subtree = xml_search_child (tree, "parent");
-      while (parentQty-- != 0)
+      while (parentQty-- > 0)
 	{
 	  if (!xml_get_value_int (subtree, "ref", &parentNumber))
 	    return false;
